cmoncrawl.processor.pipeline.extractor.IExtractor.\_\_init\_\_
==============================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. automethod:: IExtractor.__init__